@@ -47,7 +47,9 @@ class TestTreeView(ttk.Frame):
         self.tree.bind("<<TreeviewSelect>>", self._on_select, True)
 
         # configure the only tree column
-        self.tree.column("#0", anchor=tk.W, stretch=True)
+        # ajout ici
+        self.tree.column("#0", anchor=tk.W, width = 100, stretch=True)
+        #        self.tree.column("#0", anchor=tk.W, stretch=True)
         # self.tree.heading('#0', text='Item (type @ line)', anchor=tk.W)
         self.tree["show"] = ("tree",)
 
